@@ -491,7 +491,7 @@ class GLTFExporter(object):
         # still, we keep the former name for uniformity
 
         if cmds.objectType(mLightProbe) == 'v3dReflectionCubemap':
-            probe['type'] = 'CUBEMAP'
+            probe['type'] = 'SPHERE'
 
             influenceType = rc.getVolumeTypeName(cmds.getAttr(mLightProbe
                     + '.influenceType'))
@@ -527,7 +527,7 @@ class GLTFExporter(object):
             probe['influenceGroupInv'] = cmds.getAttr(mLightProbe
                     + '.invertInfluenceSelectionSet')
         elif cmds.objectType(mLightProbe) == 'v3dReflectionPlane':
-            probe['type'] = 'PLANAR'
+            probe['type'] = 'PLANE'
 
             probe['influenceDistance'] = cmds.getAttr(mLightProbe + '.influenceDistance')
             probe['falloff'] = cmds.getAttr(mLightProbe + '.falloff')
@@ -747,11 +747,6 @@ class GLTFExporter(object):
 
             v3dExt['colorSpace'] = mayaUtils.extractTextureColorSpace(mTex)
 
-            uvTransform = mayaUtils.calcUvTransformMatrix(mTex)
-
-            if uvTransform:
-                v3dExt['uvTransform'] = uvTransform
-
             texSettings = customAttrs.parseTextureSettings(mTex)
 
             anisotropy = texSettings['anisotropy']
@@ -973,7 +968,12 @@ class GLTFExporter(object):
 
             v3dExt['nodeGraph'] = matNodes.extractNodeGraph(matNodes.nodeGraphSG(mMat), self.output, shape)
 
-            if matSettings['alphaMode'] == 'COVERAGE':
+            if matSettings['alphaMode'] == 'BLEND':
+                if matSettings['transparencyHack'] == 'NEAREST_LAYER':
+                    v3dExt['depthPrepass'] = True
+                elif matSettings['transparencyHack'] == 'TWO_PASS' and matSettings['twoSided']:
+                    v3dExt['renderSide'] = 'TWO_PASS_DOUBLE';
+            elif matSettings['alphaMode'] == 'COVERAGE':
                 v3dExt['alphaToCoverage'] = True
             elif matSettings['alphaMode'] == 'ADD':
                 blendMode = gltf.createBlendMode('FUNC_ADD', 'ONE', 'ONE')
@@ -982,7 +982,7 @@ class GLTFExporter(object):
             # disable GTAO for BLEND materials due to implementation issues
             v3dExt['gtaoVisible'] = matSettings['alphaMode'] != 'BLEND'
 
-            if not matSettings['depthWrite']:
+            if alphaMode != 'OPAQUE' and not matSettings['depthWrite']:
                 v3dExt['depthWrite'] = False
 
             if not matSettings['depthTest']:
@@ -1254,19 +1254,20 @@ class GLTFExporter(object):
 
         style = cmds.getAttr(mType + '.currentStyle')
 
-        bold = 0
-        italic = 0
+        bold = False
+        italic = False
 
         if style == 'Bold':
-            bold = 1
+            bold = True
         elif style == 'Italic':
-            italic = 1
+            italic = True
         elif style == 'Bold Italic':
-            bold = 1
-            italic = 1
+            bold = True
+            italic = True
 
         filePath = sysfont.match_font(name, bold, italic)
-        if filePath:
+        # NOTE: TrueType Collection files are not yet supported by opentype.js
+        if filePath and os.path.splitext(filePath)[1] != '.ttc':
             fileNameExp = os.path.basename(filePath)
             mimeType = 'font/ttf'
         else:
@@ -1829,7 +1830,7 @@ class GLTFExporter(object):
             gltfEncoded = json.dumps(self.output, sort_keys=True, indent=indent,
                                      separators=separators, ensure_ascii=False)
 
-            with open(settings['filepath'], 'w', encoding='utf8') as outfile:
+            with open(settings['filepath'], 'w', encoding='utf8', newline='\n') as outfile:
                 outfile.write(gltfEncoded)
 
             if not settings['sneakPeek'] and settings['lzmaEnabled']:
