@@ -145,18 +145,8 @@ def runUserManual(c=None):
     cmds.launch(webPage=AppManagerConn.getManualURL())
 
 def runReexportAll(c=None):
-    apps = join(getRoot(), 'applications')
-
-    for root, dirs, files in os.walk(apps):
-        for name in files:
-            if fnmatch.fnmatch(name, '*.mb') or fnmatch.fnmatch(name, '*.ma'):
-                mayapath = os.path.normpath(join(root, name))
-
-                gltfpath = pluginUtils.path.findExportedAssetPath(mayapath)
-                if gltfpath:
-                    print('Reexporting', name)
-                    cmds.file(mayapath, open=True, force=True)
-                    cmds.file(gltfpath, exportAll=True, type='Verge3D glTF', force=True)
+    s = ReexportDialog()
+    s.create()
 
 def initRuntimeCommands(pluginPath):
     manualURL = AppManagerConn.getManualURL()
@@ -271,7 +261,7 @@ class SettingsDialog():
         if cmds.window(self.winName, exists=True):
             cmds.deleteUI(self.winName)
 
-        cmds.window(self.winName, title=self.winTitle, resizeToFitChildren=True)#height=100)
+        cmds.window(self.winName, title=self.winTitle, resizeToFitChildren=True)
 
         tabs = cmds.tabLayout(innerMarginWidth=5, innerMarginHeight=5)
 
@@ -357,6 +347,105 @@ class SettingsDialog():
         self.shadowFilteringChanged()
         cmds.showWindow(self.winName)
 
+
+class ReexportDialog():
+    def __init__(self, winName='v3d_reexport'):
+        self.winTitle = 'Reexport all Verge3D Assets'
+        self.winName = winName
+
+        self.folderUI = None
+        self.resaveMayaUI = None
+        self.updateCopyrightUI = None
+        self.forceGLBUI = None
+
+    def onCancel(self):
+        cmds.deleteUI(self.winName, window=True)
+
+    def openMayaScene(self, mayapath, mayapathRel):
+        cmds.file(mayapath, open=True, ignoreVersion=True, force=True)
+        mayaVer = cmds.about(apiVersion=True) // 10000
+        try:
+            fileVer = int(cmds.fileInfo('version', query=True)[0])
+        except ValueError:
+            # NOTE: handle cases when version is equal to "Preview Release"
+            fileVer = 2000
+        if mayaVer < fileVer:
+            log.error(f'Failed to open "{mayapathRel}". Using Maya {mayaVer}, file saved in {fileVer}')
+            return False
+        else:
+            return True
+
+    def updateCopyrightAttr(self):
+        if cmds.checkBox(self.updateCopyrightUI, query=True, value=True):
+            if cmds.ls(type='v3dSettings'):
+                cmds.setAttr('v3dSettings.copyright', pluginUtils.copyrightLine, type='string')
+            else:
+                log.warning('Unable to update copyright, no v3dSettings node present')
+
+    def onRun(self):
+        folder = cmds.textField(self.folderUI, query=True, text=True)
+        resaveMaya = cmds.checkBox(self.resaveMayaUI, query=True, value=True)
+        forceGLB = cmds.checkBox(self.forceGLBUI, query=True, value=True)
+
+        apps = join(getRoot(), folder)
+
+        for root, dirs, files in os.walk(apps):
+            for name in files:
+                if fnmatch.fnmatch(name, '*.mb') or fnmatch.fnmatch(name, '*.ma'):
+                    mayapath = os.path.normpath(join(root, name))
+                    mayapathRel = os.path.relpath(mayapath, getRoot())
+
+                    gltfpath = pluginUtils.path.findExportedAssetPath(mayapath)
+                    if gltfpath:
+                        if forceGLB:
+                            gltfpath = os.path.splitext(gltfpath)[0] + '.glb'
+
+                        print() # empty line improves readability
+
+                        log.info(f'Reexporting "{mayapathRel}"')
+                        if self.openMayaScene(mayapath, mayapathRel):
+                            self.updateCopyrightAttr()
+                            exportGLTFPath(gltfpath)
+                            if resaveMaya:
+                                log.info(f'Resaving "{mayapathRel}"')
+                                cmds.file(save=True, force=True)
+                    elif resaveMaya:
+                        if self.openMayaScene(mayapath, mayapathRel):
+                            log.info(f'Resaving "{mayapathRel}"')
+                            self.updateCopyrightAttr()
+                            cmds.file(save=True, force=True)
+
+        self.onCancel()
+
+    def create(self):
+        if cmds.window(self.winName, exists=True):
+            cmds.deleteUI(self.winName)
+
+        cmds.window(self.winName, title=self.winTitle, resizeToFitChildren=True)
+
+        # COMPAT: no margins in Maya < 2024
+        if (cmds.about(apiVersion=True) // 10000) < 2024:
+            cmds.columnLayout(adjustableColumn=True, rowSpacing=10)
+        else:
+            cmds.columnLayout(adjustableColumn=True, rowSpacing=10, margins=10)
+
+        cmds.rowLayout(numberOfColumns=2, adjustableColumn=2)
+        cmds.text(label="Folder:")
+        self.folderUI = cmds.textField(text="applications")
+        cmds.setParent('..')
+
+        self.resaveMayaUI = cmds.checkBox(label="Resave .mb/.ma files", value=False)
+        self.updateCopyrightUI = cmds.checkBox(label="Update copyright", value=False)
+        self.forceGLBUI = cmds.checkBox(label="Force GLB export", value=False)
+
+        cmds.rowLayout(numberOfColumns=2)
+        cmds.button(label="Cancel", width=100, command=lambda *args: self.onCancel())
+        cmds.button(label="Run", width=100, command=lambda *args: self.onRun())
+        cmds.setParent('..')
+
+        cmds.setParent('..')
+        cmds.showWindow(self.winName)
+
 def resetFrameLayout(frameLayoutName, label, new, collapse=False):
     if new:
         cmds.frameLayout(frameLayoutName, label=label, collapse=collapse)
@@ -650,13 +739,32 @@ def materialSettingsUIReplace(nodeAttr):
 
 def materialSettingsUI(nodeAttr, new):
 
+    transHackCtl = None
+    depthWriteCtl = None
+
+    def alphaModeChanged():
+        nonlocal transHackCtl, depthWriteCtl
+
+        idx = cmds.getAttr(nodeAttr+'v3d.alphaMode')
+
+        if customAttrs.ALPHA_MODE_MAP[idx] == 'OPAQUE':
+            cmds.control(depthWriteCtl, edit=True, enable=False)
+        else:
+            cmds.control(depthWriteCtl, edit=True, enable=True)
+
+        if customAttrs.ALPHA_MODE_MAP[idx] == 'BLEND':
+            cmds.control(transHackCtl, edit=True, enable=True)
+        else:
+            cmds.control(transHackCtl, edit=True, enable=False)
+
     origParent = cmds.setParent(q=True)
 
     resetFrameLayout('AEV3DMaterialSettings', 'Custom Settings', new)
 
-    cmds.attrControlGrp(attribute=nodeAttr+'v3d.alphaMode')
+    cmds.attrControlGrp(attribute=nodeAttr+'v3d.alphaMode', changeCommand=alphaModeChanged)
+    transHackCtl = cmds.attrControlGrp(attribute=nodeAttr+'v3d.transparencyHack')
     cmds.attrControlGrp(attribute=nodeAttr+'v3d.twoSided')
-    cmds.attrControlGrp(attribute=nodeAttr+'v3d.depthWrite')
+    depthWriteCtl = cmds.attrControlGrp(attribute=nodeAttr+'v3d.depthWrite')
     cmds.attrControlGrp(attribute=nodeAttr+'v3d.depthTest')
     cmds.attrControlGrp(attribute=nodeAttr+'v3d.dithering')
 
@@ -665,6 +773,7 @@ def materialSettingsUI(nodeAttr, new):
 
     cmds.setParent(origParent)
 
+    alphaModeChanged()
 
 def textureSettingsUINew(nodeAttr):
     textureSettingsUI(nodeAttr, True)
