@@ -1471,44 +1471,6 @@ def getUvWrapInfo(mTex):
         info['wrapV'] = not (cmds.getAttr(mTex + '.twrap') == 2)
     return info
 
-
-def calcUvTransformMatrix(mTex):
-
-    p2dTex = getInputNode(mTex, 'uvCoord')
-
-    if not p2dTex or cmds.objectType(p2dTex) != 'place2dTexture':
-        return None
-
-    uOffset = cmds.getAttr(p2dTex + '.offset')[0][0]
-    vOffset = cmds.getAttr(p2dTex + '.offset')[0][1]
-    uTiling = cmds.getAttr(p2dTex + '.repeatUV')[0][0]
-    vTiling = cmds.getAttr(p2dTex + '.repeatUV')[0][1]
-
-    angle = -math.radians(cmds.getAttr(p2dTex + '.rotateUV'))
-
-    if uOffset == 0 and vOffset == 0 and uTiling == 1 and vTiling == 1 and angle == 0:
-        return None
-
-    sx = uTiling
-    sy = vTiling
-
-    tx = uOffset
-    ty = vOffset
-
-    cx = 0.5
-    cy = 0.5
-
-    cos = math.cos
-    sin = math.sin
-
-    # column major
-    # M_flip x M_cx_cy x M_rot x M_cx_cy_inv x M_tx_ty x M_scale x Mflip
-    return [
-        cos(angle)*sx,  sin(angle)*sx, 0,
-        -sin(angle)*sy, cos(angle)*sy, 0,
-        sin(angle)*(ty+sy-cy)+cos(angle)*(tx-cx)+cx, -cos(angle)*(ty+sy-cy)+sin(angle)*(tx-cx)-cy+1, 1
-    ]
-
 def queryAreaLight(mLight, query=True, rgb=False, intensity=False, decayRate=False):
     if rgb == True:
         return cmds.getAttr(mLight + '.color')[0]
